// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function value = number_cget (key)
  //   Returns the value of an option.
  //
  // Calling Sequence
  //   value = number_cget (key)
  //
  // Parameters
  //   key : a 1x1 matrix of strings, the name of the option
  //   value : the value of the option
  //
  // Description
  //   Returns the value of an option.
  //   The values available for key are the same as in number_configure.
  //
  // Examples
  //   value = number_cget ( "-verbose" )
  //   number_configure ( "-verbose" , 1 );
  //   value = number_cget ( "-verbose" )
  //   number_configure ( "-verbose" , 0 );
  //   value = number_cget ( "-verbose" )
  //
  //   number_cget ( "-imax" )
  //   number_cget ( "-pollardseeds" )
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  //

  global %number
  select key
  case "-verbose" then
    value = %number.verbose
  case "-pollardseeds" then
    value = %number.pollardseeds
  case "-imax" then
    value = %number.imax
  else
    errmsg = sprintf( gettext ( "%s: Unknown key %s" ) , "number_cget" , key )
    error(errmsg)
  end
endfunction

