// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
// Copyright (C) INRIA - Farid BELAHCENE
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function number_check ( n )
  //   Check that the input integer can be managed correctly.
  //
  // Calling Sequence
  //   number_check ( n )
  //
  // Parameters
  //   n : a 1x1 matrix of floating point integers
  //
  // Description
  //   If not, generates an error.
  //   Performs the following checkings :
  //   <itemizedlist>
  //   <listitem> checks that this is a real type variable</listitem>
  //   <listitem> check that it is in the interval [-2^53,2^53]</listitem>
  //   <listitem> check that there is no fraction part in the value (floor(n) and n
  //     should be equal)</listitem>
  //   <listitem> check that n is a scalar (its size is 1)</listitem>
  //   </itemizedlist>
  //
  // Examples
  // number_check ( 10 )
  //
  // // Generate an error
  // number_check ( "n" )
  // number_check ( 1e308 )
  // number_check ( 1.5 )
  // number_check ( [1 1] )
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  // Copyright (C) INRIA - Farid BELAHCENE
  //

  if ( type(n)<>1 ) then
    error(msprintf(gettext("%s: Wrong type for integer %s: A real expected.\n"),"number_check" , string(n) ));
  end
  number_checkrange ( n )
  if ( n - floor(n) <> 0 )
        error(msprintf(gettext ( "%s: Wrong value for integer %s: This is not an integer.") , "number_check" , string(n) ))
  end
  if ( prod(size(n,"*"))<>1 ) then
    error(msprintf(gettext("%s: Wrong size for input argument [%s]: A scalar is expected but current size is %d x %d.\n"),"number_check" , strcat ( string(n), " ") , size(n,1) , size(n,2)));
  end	
endfunction

