// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function number_configure ( key , value )
  //   Configure the number library.
  //
  // Calling Sequence
  //   number_configure ( key , value )
  //
  // Parameters
  //   key : a 1x1 matrix of strings, the name of the option
  //   value : the value of the option
  //
  // Description
  //   Configure the toolbox with the given value for the
  //   given key. 
  //   If the key is unknown, generates an error.
  //
  //    The following keys are available.
  //    <variablelist>
  //      <varlistentry>
  //        <term>key = "-verbose"</term>
  //        <listitem>
  //        <para>set to 1 to enable verbose logging. (default is
  //        0)</para>
  //        </listitem>
  //      </varlistentry>
  //      <varlistentry>
  //        <term>key = "-imax"</term>
  //        <listitem>
  //        <para>
  //        the maximum number of iterations in the algorithms ( default 10000 )
  //        </para>
  //        </listitem>
  //      </varlistentry>
  //      <varlistentry>
  //        <term>key = "-pollardseeds"</term>
  //        <listitem>
  //        <para>
  //        the seeds used in Pollard's algorithm for factoring in number_factor.
  //        The default value is [-3 1 3 5].
  //        </para>
  //        </listitem>
  //      </varlistentry>
  //    </variablelist>
  //
  // Examples
  //   number_configure ( "-verbose" , 1 );
  //   number_configure ( "-verbose" , 0 );
  //
  //   number_configure ( "-imax" , 10 );
  //   number_configure ( "-imax" , 100 );
  //
  //   number_configure ( "-pollardseeds" , [-3 1 3 5] );
  //   number_configure ( "-pollardseeds" , [-5 -3 1 3 5] );
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  //

  global %number
  select key
  case "-verbose" then
    %number.verbose = value
  case "-pollardseeds" then
    %number.pollardseeds = value
  case "-imax" then
    if ( value < 0. ) then
      errmsg = sprintf( gettext ( "%s: Maximum number of iterations is negative: %e" ) ,"number_configure" , value )
      error(errmsg)
    end
    %number.imax = value
  else
    errmsg = sprintf( gettext ( "%s: Unknown key %s" ) , "number_configure" , key )
    error(errmsg)
  end
endfunction


