// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin

// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = number_inversemod ( a , n )
  // Computes the modular multiplicative inverse.
  // 
  // Calling Sequence
  // x = number_inversemod ( a , n )
  //
  // Parameters
  // a : a 1x1 matrix of floating point integers, must be positive
  // n : a 1x1 matrix of floating point integers, must be positive
  // x : a 1x1 matrix of floating point integers
  //
  // Description
  //   Returns the multiplicative inverse of a modulo n,
  //   i.e. returns x such that .
  //
  //<latex>
  //\begin{eqnarray}
  //ax \equiv 1 \pmod{n}
  //\end{eqnarray}
  //</latex>
  //
  //   Uses number_solvelinmod.
  //
  // Examples
  // number_inversemod ( 3 , 11 ) // 4
  //
  // Bibliography
  //   "Introduction to algorithms", Cormen, Leiserson, Rivest, Stein, 2nd edition
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  //

  number_check ( a )
  number_checkpositive ( "a" , a )
  number_check ( n )
  number_checkpositive ( "n" , n )
  x = number_solvelinmod ( a , 1 , n )
endfunction

