// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin

// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function isdivisor = number_isdivisor ( a , b )
  // Checks if a divides b.
  //
  // Calling Sequence
  // isdivisor = number_isdivisor ( a , b )
  //
  // Parameters
  // a : a 1x1 matrix of floating point integers, must be positive
  // b : a 1x1 matrix of floating point integers, must be positive
  // isdivisor : a 1x1 matrix of booleans
  //
  // Description
  //   Returns %t if a | b.
  //   Returns %f if not.
  //
  // Examples
  // number_isdivisor ( 3 , 5 ) // %f
  // number_isdivisor ( 3 , 9 ) // %t
  //
  // Bibliography
  //   "Introduction to algorithms", Cormen, Leiserson, Rivest, Stein, 2nd edition
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  //

  number_check ( a )
  number_checkpositive ( "a" , a )
  number_check ( b )
  number_checkpositive ( "b" , b )
  if ( ( b / a ) - floor ( b / a ) == 0 ) then
    isdivisor = %t
  else
    isdivisor = %f
  end
endfunction

