// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
// Copyright (C) INRIA - Farid BELAHCENE
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function result = number_lcm ( varargin )
  // Least common multiple.
  //
  // Calling Sequence
  //   result = number_lcm ( m , n )
  //   result = number_lcm ( m , n , method )
  //
  // Parameters
  // m : a 1x1 matrix of floating point integers, must be positive
  // n : a 1x1 matrix of floating point integers, must be positive
  // method : a 1x1 matrix of strings, the algorithm to use (default method="euclidian")
  // result : a 1x1 matrix of floating point integers, the least common multiple
  //
  // Description
  // Returns the least common multiple of m and n.
  // Uses number_gcd.
  // The values of the method variable are the same as the values in number_gcd.
  //
  // Examples
  // // Test without options
  // computed = number_lcm ( 4 , 6 ) // 12 
  // computed = number_lcm ( 6 , 4 ) // 12 
  // // Test with euclidian
  // computed = number_lcm ( 4 , 6 , "euclidian" ) // 12 
  // computed = number_lcm ( 6 , 4 , "euclidian" ) // 12 
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  // Copyright (C) INRIA - Farid BELAHCENE
  //

  [lhs,rhs]=argn();
  if ( ( rhs <> 2 ) & ( rhs <> 3 ) ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while %d or %d are expected."), "number_lcm" , rhs , 2 , 3 );
    error(errmsg)
  end
  select rhs
  case 2 then
    m = varargin ( 1 )
    n = varargin ( 2 )
    method = "euclidian";
  case 3 then
    m = varargin ( 1 )
    n = varargin ( 2 )
    method = varargin ( 3 )
  end
  number_check ( m )
  number_check ( n )
  number_checkpositive ( "m" , m )
  number_checkpositive ( "n" , n )
  d = number_gcd ( m , n , method )
  // Avoid unnecessary overflows
  result = n * ( m / d )
endfunction

