// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function p = number_primorial ( n )
  // Returns the product of all primes lower or equal to n
  //
  // Calling Sequence
  // p = number_primorial ( n )
  //
  // Parameters
  // n : a 1x1 matrix of floating point integers, must be positive
  // p : a 1x1 matrix of floating point integers
  //
  // Description
  //   The primorial function p(n) is p1*p2*...*pn, 
  //   where pi are primes lower or equal than n.
  //
  // Examples
  //  number_primorial ( 2 ) // 2
  // number_primorial ( 3 ) // 2*3
  // number_primorial ( 4 ) // 2*3
  // number_primorial ( 7 ) // 2*3*5*7
  //
  // Authors
  // Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
  //

  number_check ( n )
  number_checkpositive ( "n" , n )
  primesarray = number_primes ( n )
  p = prod ( primesarray )
endfunction

