// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// Stress-tests
// Check that a reasonable behaviour occurs when the
// factoring fails.
// The reasonable behaviour is that any factor that may have been discovered
// should be stored in the final result.
//

// Test complete failure
// Try with 2 large primes
// 7349 and 7901 are two primes
number_configure ( "-imax" , 10 );
n = 7349 * 7901;
[ computed , status ] = number_factor ( n , "pollard-rho" );
assert_equal ( status , %f );
assert_equal ( computed , n );
[ computed , status ] = number_factor ( n , "trialdivision" );
assert_equal ( status , %f );
assert_equal ( computed , n );
[ computed , status ] = number_factor ( n , "memorylesstd" );
assert_equal ( status , %f );
assert_equal ( computed , n );
// A difficult test for Fermat's
// 33554431  = 1801 * 18631 = 1801 * ( 31  *  601 )
n = 1801 * 31  *  601 ;
[ computed , status ] = number_factor ( n , "fermat" );
assert_equal ( status , %f );
assert_equal ( computed , n );

// Test partial failure : check that factors which have been found
// are correctly returned
// Try with 2 large primes
// 7349 and 7901 are two primes
number_configure ( "-imax" , 10 )
n = 2 * 3 * 7349 * 7901;
// Too large for probableprime
//[ computed , status ] = number_factor ( n , "pollard-rho" );
//assert_equal ( status , %f );
//assert_equal ( computed , [ 2 3 58064449 ] );
[ computed , status ] = number_factor ( n , "trialdivision" );
assert_equal ( status , %f );
assert_equal ( computed , [ 2 3 58064449 ] );
[ computed , status ] = number_factor ( n , "memorylesstd" );
assert_equal ( status , %f );
assert_equal ( computed , [ 2 3 58064449 ] );
[ computed , status ] = number_factor ( n , "memorylesstd" );
assert_equal ( status , %f );
assert_equal ( computed , [ 2 3 58064449 ] );
// A partial factoring case for Fast trial division
n = 2^12;
[ computed , status ] = number_factor ( n , "fasttrialdivision" );
assert_equal ( status , %f );
expected = [2.    2.    2.    2.    2.    2.    2.    2.    2.    2.    4.];
assert_equal ( computed , expected );

