// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

function testprime ( method )
  // Begin with a few numbers
  integerlist  = [1  2  3  4  5  6  7  8  9  10 73 32003];
  expectedlist = [%f %t %t %f %t %f %t %f %f %f %t %t].';
  computed = [];
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    [ computed , status ] = number_isprime ( integerlist ( i ) , method );
    expected = expectedlist ( i );
    assert_equal ( computed , expected );
    assert_equal ( status , %t );
  end
  // Test some even integers
  integerlist = 2 * ( 2 : 50 );
  expected = %f;
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    [ computed , status ] = number_isprime ( integerlist ( i ) , method );
    assert_equal ( computed , expected );
    assert_equal ( status , %t );
  end
  // Test some primes
  integerlist = [
      2      3      5      7     11     13     17     19     23     29 
     31     37     41     43     47     53     59     61     67     71 
     73     79     83     89     97    101    103    107    109    113 
    127    131    137    139    149    151    157    163    167    173 
    179    181    191    193    197    199    211    223    227    229 
    233    239    241    251    257    263    269    271    277    281 
    283    293    307    311    313    317    331    337    347    349 
    353    359    367    373    379    383    389    397    401    409 
    419    421    431    433    439    443    449    457    461    463 
    467    479    487    491    499    503    509    521    523    541 
    547    557    563    569    571    577    587    593    599    601 
    607    613    617    619    631    641    643    647    653    659 
    661    673    677    683    691    701    709    719    727    733 
    739    743    751    757    761    769    773    787    797    809 
    811    821    823    827    829    839    853    857    859    863 
    877    881    883    887    907    911    919    929    937    941 
    947    953    967    971    977    983    991    997   1009   1013 
  ];
  expected = %t;
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    [ computed , status ] = number_isprime ( integerlist ( i ) , method );
    assert_equal ( computed , expected );
    assert_equal ( status , %t );
  end
endfunction
// Test isprime in regular situation
testprime ( "primes" )
testprime ( "modulo" )
testprime ( "6k" )
testprime ( "30k" )
testprime ( "210k" )
testprime ( "massdivide" )

