// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
// Check for actual primes
assert_equal ( number_pseudoprime ( 7 ) , %t );
assert_equal ( number_pseudoprime ( 5 ) , %t );
assert_equal ( number_pseudoprime ( 5 , 3 ) , %t );
// Check for composite numbers
assert_equal ( number_pseudoprime ( 10 ) , %f );
assert_equal ( number_pseudoprime ( 20 ) , %f );
// Check for pseudo-primes : this is a known limitation of the test
// 341 = 11 * 31
assert_equal ( number_pseudoprime ( 341 ) , %t );
assert_equal ( number_pseudoprime ( 561 ) , %t );
assert_equal ( number_pseudoprime ( 645 ) , %t );
assert_equal ( number_pseudoprime ( 1105 ) , %t );

