// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) 2008 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

d = number_tobary ( 4 );
assert_equal ( d , [1 0 0]' );
//
basis = 2;
digits = number_tobary ( 4 , basis );
assert_equal ( digits , [1 0 0]' );
//
digits = number_tobary ( 4 , basis , "littleendian" );
assert_equal ( digits , [1 0 0]' );
//
digits = number_tobary ( 4 , basis , "bigendian" );
assert_equal ( digits , [0 0 1]' );
//
digits = number_tobary ( 4 , basis , "littleendian" , 8 );
assert_equal ( digits , [0 0 0 0 0 1 0 0]' );
//
digits = number_tobary ( 4 , basis , "bigendian" , 8 );
assert_equal ( digits , [0 0 1 0 0 0 0 0]' );
//
digits = number_tobary ( 8 , basis , "bigendian" , 8 );
assert_equal ( digits , [0 0 0 1 0 0 0 0]' );

